/*====================================+=====================================+
! File CDndChannel.h                  ! Copyright (C) 2016-2018 Remi PASCAL !
+-------------------------------------+-------------------------------------+
! This file is part of matelefree.                                          !
! matelefree is free software: you can redistribute it and/or modify it     !
! under the terms of the GNU General Public License as published by the     !
! Free Software Foundation, either version 3 of the License, or any later   !
! version.                                                                  !
! matelefree is distributed in the hope that it will be useful, but WITHOUT !
! ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or     !
! FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for !
! more details.                                                             !
! You should have received a copy of the GNU General Public License along   !
! with matelefree. If not, see <http://www.gnu.org/licenses/>.              !
+==========================================================================*/



/*-------------------------------------------------------------------------*/
#pragma once
/*-------------------------------------------------------------------------*/
#include <wx/dnd.h>
#include <wx/treectrl.h>
#include "matelefree.h"
/*-------------------------------------------------------------------------*/
class CPlaylist ;
/*-------------------------------------------------------------------------*/



/*-------------------------------------------------------------------------*/
class CChannelDataObject : public wxTextDataObject
{
   /*----------------------------------------------------------------------*/
   public :
      /*--( Use standard text or specific format ? )-----------------------*/
      explicit CChannelDataObject() : wxTextDataObject()
      {  /*SetFormat( "mtfdndchannel" )*/ ; }
      explicit CChannelDataObject( const CPlaylist *pl )
             : CChannelDataObject()
      {  set_text_from_pl_hil( pl ) ; }

   /*----------------------------------------------------------------------*/
   public :
      /*-------------------------------------------------------------------*/
      void set_text_from_pl_hil( const CPlaylist *pl ) ;
      mtf::t_vec_string data_to_vs() ;

   /*----------------------------------------------------------------------*/
} ;

/*-------------------------------------------------------------------------*/
class CChannelDropTarget : public wxDropTarget
{
   /*----------------------------------------------------------------------*/
   public :
      /*-------------------------------------------------------------------*/
      explicit CChannelDropTarget( wxWindow *win_owner )
                                 : wxDropTarget( new CChannelDataObject ),
                                   m_win_owner( win_owner )
      {  ; }

   /*----------------------------------------------------------------------*/
   protected :
      /*--( To witch window is this drop target associated ? )-------------*/
      wxWindow *m_win_owner = nullptr ;

   /*----------------------------------------------------------------------*/
   public :
      /*-------------------------------------------------------------------*/
      virtual wxDragResult OnData( wxCoord x, wxCoord y,
                                   wxDragResult dr_def
                                 ) ;
      virtual void OnDropChannel( wxCoord x, wxCoord y,
                                  const mtf::t_vec_string &vs_channel
                                ) = 0 ;
   /*----------------------------------------------------------------------*/
} ;

/*-------------------------------------------------------------------------*/
class CChannelDropTargetOnPlaylist : public CChannelDropTarget
{
   /*----------------------------------------------------------------------*/
   public :
      /*-------------------------------------------------------------------*/
      explicit CChannelDropTargetOnPlaylist( wxWindow *playlist )
                                           : CChannelDropTarget( playlist )
      {  ; }

   /*----------------------------------------------------------------------*/
   public :
      /*-------------------------------------------------------------------*/
      CPlaylist *get_win_owner()
      {  return( reinterpret_cast< CPlaylist * >( m_win_owner ) ) ; }
      /*-------------------------------------------------------------------*/
      virtual void OnDropChannel( wxCoord x, wxCoord y,
                                  const mtf::t_vec_string &vs_channel
                                ) ;
      virtual wxDragResult OnDragOver( wxCoord x, wxCoord y,
                                       wxDragResult dr_def
                                     ) override ;
   /*----------------------------------------------------------------------*/
} ;

/*-------------------------------------------------------------------------*/
class CChannelDropTargetOnTree : public CChannelDropTarget
{
   /*----------------------------------------------------------------------*/
   public :
      /*-------------------------------------------------------------------*/
      explicit CChannelDropTargetOnTree( wxWindow *win )
                                       : CChannelDropTarget( win )
      {  ; }

   /*----------------------------------------------------------------------*/
   public :
      /*-------------------------------------------------------------------*/
      wxTreeCtrl *get_win_owner()
      {  return( reinterpret_cast< wxTreeCtrl * >( m_win_owner ) ) ; }
      /*-------------------------------------------------------------------*/
      virtual void OnDropChannel( wxCoord x, wxCoord y,
                                  const mtf::t_vec_string &vs_channel
                                ) ;
      virtual wxDragResult OnDragOver( wxCoord x, wxCoord y,
                                       wxDragResult dr_def
                                     ) override ;
   /*----------------------------------------------------------------------*/
} ;

/*-------------------------------------------------------------------------*/



/*==========================================================================+
!                         End of file CDndChannel.h                         !
+==========================================================================*/
